@@ -7,10 +7,10 @@ except ImportError:  # Python 2
 
 
 # Version of easydubins package
-__version__ = "1.1.0"
+__version__ = "1.2.0"
 
 # Read config file
 _cfg = _ConfigParser()
 with _resources.path("easydubins", "config.cfg") as _path:
     _cfg.read(str(_path))
-DECIMAL_ROUND = float(_cfg.get("fixed", "decimal_round"))
+DECIMAL_ROUND = int(_cfg.get("fixed", "decimal_round"))
